dj_oydiv.auth package
=====================

Submodules
----------

dj_oydiv.auth.basic module
--------------------------

.. automodule:: dj_oydiv.auth.basic
    :members:
    :undoc-members:
    :show-inheritance:

dj_oydiv.auth.decorators module
-------------------------------

.. automodule:: dj_oydiv.auth.decorators
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: dj_oydiv.auth
    :members:
    :undoc-members:
    :show-inheritance:
